package com.ruoyi.web.controller.zdsz;

import java.util.List;
import java.util.Arrays;
import java.util.concurrent.TimeUnit;

import lombok.RequiredArgsConstructor;
import javax.servlet.http.HttpServletResponse;
import javax.validation.constraints.*;
import cn.dev33.satoken.annotation.SaCheckPermission;
import org.springframework.web.bind.annotation.*;
import org.springframework.validation.annotation.Validated;
import com.ruoyi.common.annotation.RepeatSubmit;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.PageQuery;
import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.core.validate.AddGroup;
import com.ruoyi.common.core.validate.EditGroup;
import com.ruoyi.common.core.validate.QueryGroup;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.zdsz.domain.vo.ZEngineeringPipeJackingVo;
import com.ruoyi.zdsz.domain.bo.ZEngineeringPipeJackingBo;
import com.ruoyi.zdsz.service.IZEngineeringPipeJackingService;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 顶管工程
 *
 * @author ruoyi
 * @date 2023-12-25
 */
@Validated
@RequiredArgsConstructor
@RestController
@RequestMapping("/zdsz/engineeringPipeJacking")
public class ZEngineeringPipeJackingController extends BaseController {

    private final IZEngineeringPipeJackingService iZEngineeringPipeJackingService;

    /**
     * 查询顶管工程列表
     */
    @SaCheckPermission("zdsz:engineeringPipeJacking:list")
    @GetMapping("/list")
    public TableDataInfo<ZEngineeringPipeJackingVo> list(ZEngineeringPipeJackingBo bo, PageQuery pageQuery) {
        return iZEngineeringPipeJackingService.queryPageList(bo, pageQuery);
    }

    /**
     * 导出顶管工程列表
     */
    @SaCheckPermission("zdsz:engineeringPipeJacking:export")
    @Log(title = "顶管工程", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(ZEngineeringPipeJackingBo bo, HttpServletResponse response) {
        List<ZEngineeringPipeJackingVo> list = iZEngineeringPipeJackingService.queryList(bo);
        ExcelUtil.exportExcel(list, "顶管工程", ZEngineeringPipeJackingVo.class, response);
    }

    /**
     * 获取顶管工程详细信息
     *
     * @param id 主键
     */
    @SaCheckPermission("zdsz:engineeringPipeJacking:query")
    @GetMapping("/{id}")
    public R<ZEngineeringPipeJackingVo> getInfo(@NotNull(message = "主键不能为空")
                                     @PathVariable Long id) {
        return R.ok(iZEngineeringPipeJackingService.queryById(id));
    }

    /**
     * 新增顶管工程
     */
    @SaCheckPermission("zdsz:engineeringPipeJacking:add")
    @Log(title = "顶管工程", businessType = BusinessType.INSERT)
    @RepeatSubmit()
    @PostMapping()
    public R<Void> add(@Validated(AddGroup.class) @RequestBody ZEngineeringPipeJackingBo bo) {
        return toAjax(iZEngineeringPipeJackingService.insertByBo(bo));
    }

    /**
     * 修改顶管工程
     */
    @SaCheckPermission("zdsz:engineeringPipeJacking:edit")
    @Log(title = "顶管工程", businessType = BusinessType.UPDATE)
    @RepeatSubmit()
    @PutMapping()
    public R<Void> edit(@Validated(EditGroup.class) @RequestBody ZEngineeringPipeJackingBo bo) {
        return toAjax(iZEngineeringPipeJackingService.updateByBo(bo));
    }

    /**
     * 删除顶管工程
     *
     * @param ids 主键串
     */
    @SaCheckPermission("zdsz:engineeringPipeJacking:remove")
    @Log(title = "顶管工程", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public R<Void> remove(@NotEmpty(message = "主键不能为空")
                          @PathVariable Long[] ids) {
        return toAjax(iZEngineeringPipeJackingService.deleteWithValidByIds(Arrays.asList(ids), true));
    }
}
