package com.ruoyi.zdsz.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.core.domain.PageQuery;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;
import com.ruoyi.zdsz.domain.bo.ZEngineeringCivilBo;
import com.ruoyi.zdsz.domain.vo.ZEngineeringCivilVo;
import com.ruoyi.zdsz.domain.ZEngineeringCivil;
import com.ruoyi.zdsz.mapper.ZEngineeringCivilMapper;
import com.ruoyi.zdsz.service.IZEngineeringCivilService;

import java.util.List;
import java.util.Map;
import java.util.Collection;

/**
 * 民用工程Service业务层处理
 *
 * @author ruoyi
 * @date 2023-12-25
 */
@RequiredArgsConstructor
@Service
public class ZEngineeringCivilServiceImpl implements IZEngineeringCivilService {

    private final ZEngineeringCivilMapper baseMapper;

    /**
     * 查询民用工程
     */
    @Override
    public ZEngineeringCivilVo queryById(Long id){
        return baseMapper.selectVoById(id);
    }

    /**
     * 查询民用工程列表
     */
    @Override
    public TableDataInfo<ZEngineeringCivilVo> queryPageList(ZEngineeringCivilBo bo, PageQuery pageQuery) {
        LambdaQueryWrapper<ZEngineeringCivil> lqw = buildQueryWrapper(bo);
        Page<ZEngineeringCivilVo> result = baseMapper.selectVoPage(pageQuery.build(), lqw);
        return TableDataInfo.build(result);
    }

    /**
     * 查询民用工程列表
     */
    @Override
    public List<ZEngineeringCivilVo> queryList(ZEngineeringCivilBo bo) {
        LambdaQueryWrapper<ZEngineeringCivil> lqw = buildQueryWrapper(bo);
        return baseMapper.selectVoList(lqw);
    }

    private LambdaQueryWrapper<ZEngineeringCivil> buildQueryWrapper(ZEngineeringCivilBo bo) {
        Map<String, Object> params = bo.getParams();
        LambdaQueryWrapper<ZEngineeringCivil> lqw = Wrappers.lambdaQuery();
        lqw.eq(bo.getAreaId() != null, ZEngineeringCivil::getAreaId, bo.getAreaId());
        lqw.eq(bo.getBuildingId() != null, ZEngineeringCivil::getBuildingId, bo.getBuildingId());
        lqw.eq(bo.getUnitId() != null, ZEngineeringCivil::getUnitId, bo.getUnitId());
        lqw.eq(bo.getHouseId() != null, ZEngineeringCivil::getHouseId, bo.getHouseId());
        lqw.eq(StringUtils.isNotBlank(bo.getEngineeringType()), ZEngineeringCivil::getEngineeringType, bo.getEngineeringType());
        lqw.like(StringUtils.isNotBlank(bo.getHeadName()), ZEngineeringCivil::getHeadName, bo.getHeadName());
        lqw.eq(StringUtils.isNotBlank(bo.getHeadPhone()), ZEngineeringCivil::getHeadPhone, bo.getHeadPhone());
        lqw.eq(StringUtils.isNotBlank(bo.getEngineeringClassification()), ZEngineeringCivil::getEngineeringClassification, bo.getEngineeringClassification());
        return lqw;
    }

    /**
     * 新增民用工程
     */
    @Override
    public Boolean insertByBo(ZEngineeringCivilBo bo) {
        ZEngineeringCivil add = BeanUtil.toBean(bo, ZEngineeringCivil.class);
        validEntityBeforeSave(add);
        boolean flag = baseMapper.insert(add) > 0;
        if (flag) {
            bo.setId(add.getId());
        }
        return flag;
    }

    /**
     * 修改民用工程
     */
    @Override
    public Boolean updateByBo(ZEngineeringCivilBo bo) {
        ZEngineeringCivil update = BeanUtil.toBean(bo, ZEngineeringCivil.class);
        validEntityBeforeSave(update);
        return baseMapper.updateById(update) > 0;
    }

    /**
     * 保存前的数据校验
     */
    private void validEntityBeforeSave(ZEngineeringCivil entity){
        //TODO 做一些数据校验,如唯一约束
    }

    /**
     * 批量删除民用工程
     */
    @Override
    public Boolean deleteWithValidByIds(Collection<Long> ids, Boolean isValid) {
        if(isValid){
            //TODO 做一些业务上的校验,判断是否需要校验
        }
        return baseMapper.deleteBatchIds(ids) > 0;
    }
}
