package com.ruoyi.zdsz.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.core.domain.PageQuery;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;
import com.ruoyi.zdsz.domain.bo.ZEngineeringPipeJackingBo;
import com.ruoyi.zdsz.domain.vo.ZEngineeringPipeJackingVo;
import com.ruoyi.zdsz.domain.ZEngineeringPipeJacking;
import com.ruoyi.zdsz.mapper.ZEngineeringPipeJackingMapper;
import com.ruoyi.zdsz.service.IZEngineeringPipeJackingService;

import java.util.List;
import java.util.Map;
import java.util.Collection;

/**
 * 顶管工程Service业务层处理
 *
 * @author ruoyi
 * @date 2023-12-25
 */
@RequiredArgsConstructor
@Service
public class ZEngineeringPipeJackingServiceImpl implements IZEngineeringPipeJackingService {

    private final ZEngineeringPipeJackingMapper baseMapper;

    /**
     * 查询顶管工程
     */
    @Override
    public ZEngineeringPipeJackingVo queryById(Long id){
        return baseMapper.selectVoById(id);
    }

    /**
     * 查询顶管工程列表
     */
    @Override
    public TableDataInfo<ZEngineeringPipeJackingVo> queryPageList(ZEngineeringPipeJackingBo bo, PageQuery pageQuery) {
        LambdaQueryWrapper<ZEngineeringPipeJacking> lqw = buildQueryWrapper(bo);
        Page<ZEngineeringPipeJackingVo> result = baseMapper.selectVoPage(pageQuery.build(), lqw);
        return TableDataInfo.build(result);
    }

    /**
     * 查询顶管工程列表
     */
    @Override
    public List<ZEngineeringPipeJackingVo> queryList(ZEngineeringPipeJackingBo bo) {
        LambdaQueryWrapper<ZEngineeringPipeJacking> lqw = buildQueryWrapper(bo);
        return baseMapper.selectVoList(lqw);
    }

    private LambdaQueryWrapper<ZEngineeringPipeJacking> buildQueryWrapper(ZEngineeringPipeJackingBo bo) {
        Map<String, Object> params = bo.getParams();
        LambdaQueryWrapper<ZEngineeringPipeJacking> lqw = Wrappers.lambdaQuery();
        lqw.like(StringUtils.isNotBlank(bo.getEnginName()), ZEngineeringPipeJacking::getEnginName, bo.getEnginName());
        lqw.eq(StringUtils.isNotBlank(bo.getEnginAddre()), ZEngineeringPipeJacking::getEnginAddre, bo.getEnginAddre());
        lqw.eq(StringUtils.isNotBlank(bo.getEnginCode()), ZEngineeringPipeJacking::getEnginCode, bo.getEnginCode());
        lqw.eq(StringUtils.isNotBlank(bo.getConstructUnit()), ZEngineeringPipeJacking::getConstructUnit, bo.getConstructUnit());
        lqw.eq(StringUtils.isNotBlank(bo.getEnginScale()), ZEngineeringPipeJacking::getEnginScale, bo.getEnginScale());
        lqw.eq(StringUtils.isNotBlank(bo.getConstructQuality()), ZEngineeringPipeJacking::getConstructQuality, bo.getConstructQuality());
        lqw.eq(StringUtils.isNotBlank(bo.getConstructSchedule()), ZEngineeringPipeJacking::getConstructSchedule, bo.getConstructSchedule());
        return lqw;
    }

    /**
     * 新增顶管工程
     */
    @Override
    public Boolean insertByBo(ZEngineeringPipeJackingBo bo) {
        ZEngineeringPipeJacking add = BeanUtil.toBean(bo, ZEngineeringPipeJacking.class);
        validEntityBeforeSave(add);
        boolean flag = baseMapper.insert(add) > 0;
        if (flag) {
            bo.setId(add.getId());
        }
        return flag;
    }

    /**
     * 修改顶管工程
     */
    @Override
    public Boolean updateByBo(ZEngineeringPipeJackingBo bo) {
        ZEngineeringPipeJacking update = BeanUtil.toBean(bo, ZEngineeringPipeJacking.class);
        validEntityBeforeSave(update);
        return baseMapper.updateById(update) > 0;
    }

    /**
     * 保存前的数据校验
     */
    private void validEntityBeforeSave(ZEngineeringPipeJacking entity){
        //TODO 做一些数据校验,如唯一约束
    }

    /**
     * 批量删除顶管工程
     */
    @Override
    public Boolean deleteWithValidByIds(Collection<Long> ids, Boolean isValid) {
        if(isValid){
            //TODO 做一些业务上的校验,判断是否需要校验
        }
        return baseMapper.deleteBatchIds(ids) > 0;
    }
}
